/*
 * Class identifier (CLSID) functions
 *
 * Copyright (c) 2008-2013, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <common.h>
#include <memory.h>
#include <types.h>

#include "libolecf_class_identifier.h"
#include "libolecf_definitions.h"
#include "libolecf_libcerror.h"

uint8_t libolecf_class_identifier_summary_information[ 16 ] = \
	{ 0xe0, 0x85, 0x9f, 0xf2, 0xf9, 0x4f, 0x68, 0x10, 0xab, 0x91, 0x08, 0x00, 0x2b, 0x27, 0xb3, 0xd9 };

uint8_t libolecf_class_identifier_document_summary_information[ 16 ] = \
	{ 0x02, 0xd5, 0xcd, 0xd5, 0x9c, 0x2e, 0x1b, 0x10, 0x93, 0x97, 0x08, 0x00, 0x2b, 0x2c, 0xf9, 0xae };

uint8_t libolecf_class_identifier_unknown[ 16 ] = \
	{ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };

#if defined( HAVE_DEBUG_OUTPUT )

/* The class identifiers
 */
libolecf_class_identifier_definition_t libolecf_class_identifier_definitions[ ] = {
	{ libolecf_class_identifier_summary_information,		"Summary information" },
	{ libolecf_class_identifier_document_summary_information,	"Document summary information" },

	{ libolecf_class_identifier_unknown,				"Unknown" } };

#endif

#if defined( HAVE_DEBUG_OUTPUT )

/* Retrieves a string containing the name of the class identifier
 */
const char *libolecf_class_identifier_get_name(
             const uint8_t *class_identifier )
{
	int iterator = 0;

	if( class_identifier == NULL )
	{
		return( "Invalid class identifier" );
	}
	while( memory_compare(
	        ( libolecf_class_identifier_definitions[ iterator ] ).identifier,
	        libolecf_class_identifier_unknown,
	        16 ) != 0 )
	{
		if( memory_compare(
		     ( libolecf_class_identifier_definitions[ iterator ] ).identifier,
		     class_identifier,
		     16 ) == 0 )
		{
			break;
		}
		iterator++;
	}
	return(
	 ( libolecf_class_identifier_definitions[ iterator ] ).name );
}

#endif

